==> lima-swing-0.7-sources.jar: org/chorem/lima/ui/financialtransactionsearch/FinancialTransactionSearchTable.java <==
/*
 * #%L
 * Lima Swing
 * 
 * $Id: FinancialTransactionSearchTable.java 3683 2013-06-19 07:42:34Z Bavencoff $
 * $HeadURL: http://svn.chorem.org/svn/lima/tags/lima-0.7/lima-swing/src/main/java/org/chorem/lima/ui/financialtransactionsearch/FinancialTransactionSearchTable.java $
 * %%
 * Copyright (C) 2008 - 2010 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

package org.chorem.lima.ui.financialtransactionsearch;

import org.chorem.lima.ui.financialtransaction.FinancialTransactionDefaultTable;


/**
 * Table des transaction qui ajoute des comportement (keys).
 *
 * @author ore
 * @author Rémi Chapelet
 */
public class FinancialTransactionSearchTable extends FinancialTransactionDefaultTable {

    /** serialVersionUID. */
    private static final long serialVersionUID = 3133690382049594727L;

    public FinancialTransactionSearchTable() {
        super();
    }



}

==> lima-swing-0.7.1-sources.jar: org/chorem/lima/ui/financialtransactionsearch/FinancialTransactionSearchTable.java <==
/*
 * #%L
 * Lima Swing
 * 
 * $Id: FinancialTransactionSearchTable.java 3722 2013-12-31 15:05:26Z sbavencoff $
 * $HeadURL: https://svn.chorem.org/lima/tags/lima-0.7.1/lima-swing/src/main/java/org/chorem/lima/ui/financialtransactionsearch/FinancialTransactionSearchTable.java $
 * %%
 * Copyright (C) 2008 - 2010 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

package org.chorem.lima.ui.financialtransactionsearch;

import org.chorem.lima.ui.financialtransaction.FinancialTransactionDefaultTable;


/**
 * Table des transaction qui ajoute des comportement (keys).
 *
 * @author ore
 * @author Rémi Chapelet
 */
public class FinancialTransactionSearchTable extends FinancialTransactionDefaultTable<FinancialTransactionSearchViewHandler> {

    /** serialVersionUID. */
    private static final long serialVersionUID = 3133690382049594727L;

    public FinancialTransactionSearchTable(FinancialTransactionSearchViewHandler handler) {
        super(handler);
    }



}
